@@ -12,14 +12,13 @@
 #
 ##############################################################################
 
+from collections import deque
 import socket
 import sys
 import threading
 import time
-from collections import deque
 
 from .buffers import ReadOnlyFileBasedBuffer
-from .compat import reraise, tobytes
 from .utilities import build_http_date, logger, queue_logger
 
 rename_headers = {  # or keep them without the HTTP_ prefix added
@@ -41,9 +40,8 @@ hop_by_hop = frozenset(
 )
 
 
-class ThreadedTaskDispatcher(object):
-    """A Task Dispatcher that creates a thread for each task.
-    """
+class ThreadedTaskDispatcher:
+    """A Task Dispatcher that creates a thread for each task."""
 
     stop_count = 0  # Number of threads that will stop soon.
     active_count = 0  # Number of currently active threads
@@ -59,7 +57,7 @@ class ThreadedTaskDispatcher(object):
 
     def start_new_thread(self, target, thread_no):
         t = threading.Thread(
-            target=target, name="waitress-{}".format(thread_no), args=(thread_no,)
+            target=target, name=f"waitress-{thread_no}", args=(thread_no,)
         )
         t.daemon = True
         t.start()
@@ -141,7 +139,7 @@ class ThreadedTaskDispatcher(object):
         return False
 
 
-class Task(object):
+class Task:
     close_on_finish = False
     status = "200 OK"
     wrote_header = False
@@ -166,16 +164,13 @@ class Task(object):
 
     def service(self):
         try:
-            try:
-                self.start()
-                self.execute()
-                self.finish()
-            except socket.error:
-                self.close_on_finish = True
-                if self.channel.adj.log_socket_errors:
-                    raise
-        finally:
-            pass
+            self.start()
+            self.execute()
+            self.finish()
+        except OSError:
+            self.close_on_finish = True
+            if self.channel.adj.log_socket_errors:
+                raise
 
     @property
     def has_body(self):
@@ -271,7 +266,7 @@ class Task(object):
 
         self.response_headers = response_headers
 
-        first_line = "HTTP/%s %s" % (self.version, self.status)
+        first_line = f"HTTP/{self.version} {self.status}"
         # NB: sorting headers needs to preserve same-named-header order
         # as per RFC 2616 section 4.2; thus the key=lambda x: x[0] here;
         # rely on stable sort to keep relative position of same-named headers
@@ -281,7 +276,7 @@ class Task(object):
         lines = [first_line] + next_lines
         res = "%s\r\n\r\n" % "\r\n".join(lines)
 
-        return tobytes(res)
+        return res.encode("latin-1")
 
     def remove_content_length_header(self):
         response_headers = []
@@ -317,7 +312,7 @@ class Task(object):
             cl = self.content_length
             if self.chunked_response:
                 # use chunked encoding response
-                towrite = tobytes(hex(len(data))[2:].upper()) + b"\r\n"
+                towrite = hex(len(data))[2:].upper().encode("latin-1") + b"\r\n"
                 towrite += data + b"\r\n"
             elif cl is not None:
                 towrite = data[: cl - self.content_bytes_written]
@@ -345,8 +340,7 @@ class Task(object):
 
 
 class ErrorTask(Task):
-    """ An error task produces an error response
-    """
+    """An error task produces an error response"""
 
     complete = True
 
@@ -361,12 +355,11 @@ class ErrorTask(Task):
         self.response_headers.append(("Connection", "close"))
         self.close_on_finish = True
         self.content_length = len(body)
-        self.write(tobytes(body))
+        self.write(body)
 
 
 class WSGITask(Task):
-    """A WSGI task produces a response from a WSGI application.
-    """
+    """A WSGI task produces a response from a WSGI application."""
 
     environ = None
 
@@ -385,7 +378,7 @@ class WSGITask(Task):
                         # 1. "service" method in task.py
                         # 2. "service" method in channel.py
                         # 3. "handler_thread" method in task.py
-                        reraise(exc_info[0], exc_info[1], exc_info[2])
+                        raise exc_info[1]
                     else:
                         # As per WSGI spec existing headers must be cleared
                         self.response_headers = []
@@ -407,11 +400,11 @@ class WSGITask(Task):
             for k, v in headers:
                 if not k.__class__ is str:
                     raise AssertionError(
-                        "Header name %r is not a string in %r" % (k, (k, v))
+                        f"Header name {k!r} is not a string in {(k, v)!r}"
                     )
                 if not v.__class__ is str:
                     raise AssertionError(
-                        "Header value %r is not a string in %r" % (v, (k, v))
+                        f"Header value {v!r} is not a string in {(k, v)!r}"
                     )
 
                 if "\n" in v or "\r" in v:
@@ -545,6 +538,7 @@ class WSGITask(Task):
             "SERVER_PROTOCOL": "HTTP/%s" % self.version,
             "SCRIPT_NAME": url_prefix,
             "PATH_INFO": path,
+            "REQUEST_URI": request.request_uri,
             "QUERY_STRING": request.query,
             "wsgi.url_scheme": request.url_scheme,
             # the following environment variables are required by the WSGI spec
@@ -567,6 +561,11 @@ class WSGITask(Task):
             if mykey not in environ:
                 environ[mykey] = value
 
+        # Insert a callable into the environment that allows the application to
+        # check if the client disconnected. Only works with
+        # channel_request_lookahead larger than 0.
+        environ["waitress.client_disconnected"] = self.channel.check_client_disconnected
+
         # cache the environ for this request
         self.environ = environ
         return environ
