@@ -869,7 +869,7 @@ class TestErrorTask(unittest.TestCase):
         self.assertEqual(lines[0], b"HTTP/1.0 432 Too Ugly")
         self.assertEqual(lines[1], b"Connection: close")
         self.assertEqual(lines[2], b"Content-Length: 43")
-        self.assertEqual(lines[3], b"Content-Type: text/plain")
+        self.assertEqual(lines[3], b"Content-Type: text/plain; charset=utf-8")
         self.assertTrue(lines[4])
         self.assertEqual(lines[5], b"Server: waitress")
         self.assertEqual(lines[6], b"Too Ugly")
@@ -885,7 +885,7 @@ class TestErrorTask(unittest.TestCase):
         self.assertEqual(lines[0], b"HTTP/1.1 432 Too Ugly")
         self.assertEqual(lines[1], b"Connection: close")
         self.assertEqual(lines[2], b"Content-Length: 43")
-        self.assertEqual(lines[3], b"Content-Type: text/plain")
+        self.assertEqual(lines[3], b"Content-Type: text/plain; charset=utf-8")
         self.assertTrue(lines[4])
         self.assertEqual(lines[5], b"Server: waitress")
         self.assertEqual(lines[6], b"Too Ugly")
@@ -902,7 +902,7 @@ class TestErrorTask(unittest.TestCase):
         self.assertEqual(lines[0], b"HTTP/1.1 432 Too Ugly")
         self.assertEqual(lines[1], b"Connection: close")
         self.assertEqual(lines[2], b"Content-Length: 43")
-        self.assertEqual(lines[3], b"Content-Type: text/plain")
+        self.assertEqual(lines[3], b"Content-Type: text/plain; charset=utf-8")
         self.assertTrue(lines[4])
         self.assertEqual(lines[5], b"Server: waitress")
         self.assertEqual(lines[6], b"Too Ugly")
@@ -919,7 +919,7 @@ class TestErrorTask(unittest.TestCase):
         self.assertEqual(lines[0], b"HTTP/1.1 432 Too Ugly")
         self.assertEqual(lines[1], b"Connection: close")
         self.assertEqual(lines[2], b"Content-Length: 43")
-        self.assertEqual(lines[3], b"Content-Type: text/plain")
+        self.assertEqual(lines[3], b"Content-Type: text/plain; charset=utf-8")
         self.assertTrue(lines[4])
         self.assertEqual(lines[5], b"Server: waitress")
         self.assertEqual(lines[6], b"Too Ugly")
